@@ -18,7 +18,7 @@ use core::fmt::{self, Write};
 ///
 /// All characters are written as is except `"`, `&`, `'`, `<`, and `>` which are printed as e.g.
 /// `&#34;`.
-pub struct XmlEscape<T: ?Sized + fmt::Display>(pub T);
+pub struct XmlEscape<T: ?Sized>(pub T);
 
 impl<T: ?Sized + fmt::Display> fmt::Display for XmlEscape<T> {
     #[inline]
@@ -27,6 +27,13 @@ impl<T: ?Sized + fmt::Display> fmt::Display for XmlEscape<T> {
     }
 }
 
+impl<T: ?Sized + fmt::Debug> fmt::Debug for XmlEscape<T> {
+    #[inline]
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(XmlEscapeWriter(f), "{:?}", &self.0)
+    }
+}
+
 struct XmlEscapeWriter<'a, 'b>(&'a mut fmt::Formatter<'b>);
 
 impl fmt::Write for XmlEscapeWriter<'_, '_> {
